RPMTWApiClient class

Constructors

RPMTWApiClient({bool development = false, String? apiBaseUrl, String? universeChatBaseUrl, String? token, Client? httpClient})

Properties

apiBaseUrl → String
no setter
apiGlobalToken → String?
no setter
authResource → AuthResource
no setter
commentResource → CommentResource
no setter
curseforgeResource → CurseForgeResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
minecraftResource → MinecraftResource
no setter
otherResource → OtherResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageResource → StorageResource
no setter
translateResource → TranslateResource
no setter
universeChatBaseUrl → String
no setter
universeChatResource → UniverseChatResource
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setGlobalToken(String value) → void
Set the global token for all requests.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → RPMTWApiClient
no setter
version → String
no setter

Static Methods

init({bool development = false, String? apiBaseUrl, String? universeChatBaseUrl, String? token}) → RPMTWApiClient
Initializes the client